@@ -28,6 +28,8 @@ class Exporter:
         Returns:
 
         """
+        arg_group.add_argument('--async', action='store_true', dest='is_async',
+                               help='define accesses to register model as asynchronous')
         arg_group.add_argument('--autoformat', action='store_true',
                                 help='use autopep8 on generated code')
         arg_group.add_argument('--user_template_dir', action='store', type=pathlib.Path,
@@ -47,13 +49,16 @@ class Exporter:
 
         """
         if options.user_template_dir is None:
-            peakrdl_exporter = PythonExporter()
+            peakrdl_exporter = PythonExporter()  # type: ignore[no-untyped-call]
         else:
-            peakrdl_exporter = PythonExporter(user_template_dir=options.user_template_dir)
+            templates = options.user_template_dir
+            peakrdl_exporter = \
+                PythonExporter(user_template_dir=templates) # type: ignore[no-untyped-call]
 
         peakrdl_exporter.export(
             top_node,
             options.output,
+            options.is_async,
             autoformatoutputs=options.autoformat,
             skip_test_case_generation=options.skip_test_case_generation
         )
